summary refs log tree commit diff
path: root/src/libnm-platform/nm-platform.h
diff options
context:
space:
mode:
authorMichael Biebl <biebl@debian.org>2024-08-09 18:57:15 +0200
committerMichael Biebl <biebl@debian.org>2024-08-09 18:57:15 +0200
commite96d74409128c6a977e31f24fad9b267d2feb9a1 (patch)
tree12dad71135c6c291de457568cb973208ea8a0024 /src/libnm-platform/nm-platform.h
parent45a364c60a9d6d34e614c4f1f507c69336ad1e69 (diff)
New upstream version 1.48.8 upstream/1.48.8
Diffstat (limited to 'src/libnm-platform/nm-platform.h')
-rw-r--r--src/libnm-platform/nm-platform.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/src/libnm-platform/nm-platform.h b/src/libnm-platform/nm-platform.h
index f6a6ba08..b05b1297 100644
--- a/src/libnm-platform/nm-platform.h
+++ b/src/libnm-platform/nm-platform.h
@@ -198,7 +198,7 @@ struct _NMPlatformLink {
     /* NMPlatform initializes this field with a static string. */
     const char *driver;
 
-    int master;
+    int controller;
 
     /* rtnl_link_get_link(), IFLA_LINK.
      * If IFLA_LINK_NETNSID indicates that the parent is in another namespace,
@@ -241,11 +241,11 @@ struct _NMPlatformLink {
     /* an interface can only hold IFLA_INFO_SLAVE_DATA for one link type */
     NMPlatformLinkPortData port_data;
 
-    /* IFLA_INFO_SLAVE_KIND */
+    /* IFLA_INFO_PORT_KIND */
     NMPortKind port_kind;
 
     /* @connected is mostly identical to (@n_ifi_flags & IFF_UP). Except for bridge/bond masters,
      * where we coerce the link as disconnect if it has no slaves. */
     bool connected : 1;
 
     bool initialized : 1;
@@ -1052,7 +1052,7 @@ typedef enum {
      * were added at the same time. */
     NM_PLATFORM_KERNEL_SUPPORT_TYPE_FRA_IP_PROTO,
 
-    NM_PLATFORM_KERNEL_SUPPORT_TYPE_IFLA_BOND_SLAVE_PRIO,
+    NM_PLATFORM_KERNEL_SUPPORT_TYPE_IFLA_BOND_PORT_PRIO,
 
     _NM_PLATFORM_KERNEL_SUPPORT_NUM,
 } NMPlatformKernelSupportType;
@@ -1187,7 +1187,7 @@ typedef struct {
     gboolean (*link_set_sriov_vfs)(NMPlatform *self, int ifindex, const NMPlatformVF *const *vfs);
     gboolean (*link_set_bridge_vlans)(NMPlatform                        *self,
                                       int                                ifindex,
-                                      gboolean                           on_master,
+                                      gboolean                           on_controller,
                                       const NMPlatformBridgeVlan *const *vlans);
     gboolean (*link_set_bridge_info)(NMPlatform                            *self,
                                      int                                    ifindex,
@@ -1206,8 +1206,8 @@ typedef struct {
     gboolean (*link_supports_vlans)(NMPlatform *self, int ifindex);
     gboolean (*link_supports_sriov)(NMPlatform *self, int ifindex);
 
-    gboolean (*link_enslave)(NMPlatform *self, int master, int slave);
-    gboolean (*link_release)(NMPlatform *self, int master, int slave);
+    gboolean (*link_attach_port)(NMPlatform *self, int controller, int port);
+    gboolean (*link_release_port)(NMPlatform *self, int controller, int port);
 
     gboolean (*link_can_assume)(NMPlatform *self, int ifindex);
 
@@ -1973,12 +1973,12 @@ int         nm_platform_link_get_inet6_addr_gen_mode(NMPlatform *self, int ifind
 
 gconstpointer nm_platform_link_get_address(NMPlatform *self, int ifindex, size_t *length);
 
-int nm_platform_link_get_master(NMPlatform *self, int slave);
+int nm_platform_link_get_controller(NMPlatform *self, int port);
 
 gboolean nm_platform_link_can_assume(NMPlatform *self, int ifindex);
 
 NMOptionBool nm_platform_link_get_unmanaged(NMPlatform *self, int ifindex);
-gboolean     nm_platform_link_supports_slaves(NMPlatform *self, int ifindex);
+gboolean     nm_platform_link_supports_ports(NMPlatform *self, int ifindex);
 const char  *nm_platform_link_get_type_name(NMPlatform *self, int ifindex);
 
 gboolean nm_platform_link_refresh(NMPlatform *self, int ifindex);
@@ -2051,7 +2051,7 @@ gboolean
 nm_platform_link_set_sriov_vfs(NMPlatform *self, int ifindex, const NMPlatformVF *const *vfs);
 gboolean nm_platform_link_set_bridge_vlans(NMPlatform                        *self,
                                            int                                ifindex,
-                                           gboolean                           on_master,
+                                           gboolean                           on_controller,
                                            const NMPlatformBridgeVlan *const *vlans);
 gboolean nm_platform_link_set_bridge_info(NMPlatform                            *self,
                                           int                                    ifindex,
@@ -2070,19 +2070,19 @@ gboolean nm_platform_link_supports_carrier_detect(NMPlatform *self, int ifindex)
 gboolean nm_platform_link_supports_vlans(NMPlatform *self, int ifindex);
 gboolean nm_platform_link_supports_sriov(NMPlatform *self, int ifindex);
 
-gboolean nm_platform_link_enslave(NMPlatform *self, int master, int slave);
-gboolean nm_platform_link_release(NMPlatform *self, int master, int slave);
+gboolean nm_platform_link_attach_port(NMPlatform *self, int controller, int port);
+gboolean nm_platform_link_release_port(NMPlatform *self, int controller, int port);
 
-gboolean nm_platform_sysctl_master_set_option(NMPlatform *self,
-                                              int         ifindex,
-                                              const char *option,
-                                              const char *value);
-char    *nm_platform_sysctl_master_get_option(NMPlatform *self, int ifindex, const char *option);
-gboolean nm_platform_sysctl_slave_set_option(NMPlatform *self,
-                                             int         ifindex,
-                                             const char *option,
-                                             const char *value);
-char    *nm_platform_sysctl_slave_get_option(NMPlatform *self, int ifindex, const char *option);
+gboolean nm_platform_sysctl_controller_set_option(NMPlatform *self,
+                                                  int         ifindex,
+                                                  const char *option,
+                                                  const char *value);
+char *nm_platform_sysctl_controller_get_option(NMPlatform *self, int ifindex, const char *option);
+gboolean nm_platform_sysctl_port_set_option(NMPlatform *self,
+                                            int         ifindex,
+                                            const char *option,
+                                            const char *value);
+char    *nm_platform_sysctl_port_get_option(NMPlatform *self, int ifindex, const char *option);
 
 const NMPObject *nm_platform_link_get_lnk(NMPlatform            *self,
                                           int                    ifindex,
@@ -2569,7 +2569,7 @@ void nm_platform_mptcp_addr_hash_update(const NMPlatformMptcpAddr *obj, NMHashSt
 guint    nm_platform_mptcp_addr_index_addr_cmp(gconstpointer data);
 gboolean nm_platform_mptcp_addr_index_addr_equal(gconstpointer data_a, gconstpointer data_b);
 
-#define NM_PLATFORM_LINK_FLAGS2STR_MAX_LEN ((gsize) 162)
+#define NM_PLATFORM_LINK_FLAGS2STR_MAX_LEN ((gsize) 165)
 
 gboolean nm_platform_ethtool_set_wake_on_lan(NMPlatform              *self,
                                              int                      ifindex,
@@ -241,11 +241,11 @@ struct _NMPlatformLink {
     NMPortKind port_kind;
 
-    /* @connected is mostly identical to (@n_ifi_flags & IFF_UP). Except for bridge/bond masters,
-     * where we coerce the link as disconnect if it has no slaves. */
+    /* @connected is mostly identical to (@n_ifi_flags & IFF_UP). Except for bridge/bond controllers,
+     * where we coerce the link as disconnect if it has no ports. */
     bool connected : 1;
 